@@ -38,7 +38,7 @@ store_aws_bucket <- function(path) {
     return(path[1L])
   }
   # with metadata written by targets > 0.8.1:
-  store_aws_field(path = path, pattern = "^bucket=")
+  store_aws_path_field(path = path, pattern = "^bucket=")
 }
 
 store_aws_region <- function(path) {
@@ -47,7 +47,7 @@ store_aws_region <- function(path) {
     return()
   }
   # with metadata written by targets > 0.8.1:
-  out <- store_aws_field(path = path, pattern = "^region=")
+  out <- store_aws_path_field(path = path, pattern = "^region=")
   out <- if_any(length(out) > 0L && any(nzchar(out)), out, "")
   if_any(identical(out, "NULL"), NULL, out)
 }
@@ -57,20 +57,19 @@ store_aws_key <- function(path) {
   if (store_aws_path_0.8.1(path)) {
     return(path[2L])
   }
-  store_aws_field(path = path, pattern = "^key=")
+  store_aws_path_field(path = path, pattern = "^key=")
+}
+
+store_aws_path_field <- function(path, pattern) {
+  path <- store_aws_split_colon(path)
+  keyvalue_field(x = path, pattern = pattern)
 }
 
 store_aws_version <- function(path) {
-  out <- store_aws_field(path = path, pattern = "^version=")
+  out <- store_aws_path_field(path = path, pattern = "^version=")
   if_any(length(out) && nzchar(out), out, NULL)
 }
 
-store_aws_field <- function(path, pattern) {
-  path <- store_aws_split_colon(path)
-  element <- grep(pattern = pattern, x = path, value = TRUE)
-  gsub(pattern = pattern, replacement = "", x = element)
-}
-
 store_aws_path_0.8.1 <- function(path) {
   !any(grepl(pattern = "^bucket=", x = path))
 }
@@ -100,7 +99,7 @@ store_read_object.tar_aws <- function(store) {
     region = store_aws_region(path),
     version = store_aws_version(path)
   )
-  store_cast_object(store, store_read_path(store, tmp))
+  store_convert_object(store, store_read_path(store, tmp))
 }
 
 #' @export
@@ -134,16 +133,6 @@ store_upload_object.tar_aws <- function(store) {
   invisible()
 }
 
-store_aws_hash <- function(key, bucket, region, version) {
-  head <- aws_s3_head(
-    key = key,
-    bucket = bucket,
-    region = region,
-    version = version
-  )
-  head$Metadata[["targets-hash"]]
-}
-
 #' @export
 store_has_correct_hash.tar_aws <- function(store) {
   path <- store$file$path
@@ -170,6 +159,16 @@ store_has_correct_hash.tar_aws <- function(store) {
     FALSE
   )
 }
+
+store_aws_hash <- function(key, bucket, region, version) {
+  head <- aws_s3_head(
+    key = key,
+    bucket = bucket,
+    region = region,
+    version = version
+  )
+  head$Metadata[["targets-hash"]]
+}
 # nocov end
 
 #' @export
