@@ -1,5 +1,5 @@
 #' @export
-store_new.aws_fst_tbl <- function(class, file = NULL, resources = NULL) {
+store_new.aws_fst_tbl <- function(format, file = NULL, resources = NULL) {
   aws_fst_tbl_new(file = file, resources = resources)
 }
 
@@ -21,5 +21,5 @@ aws_fst_tbl_new <- function(file = NULL, resources = NULL) {
 }
 
 #' @export
-store_assert_format_setting.aws_fst_tbl <- function(class) {
+store_assert_format_setting.aws_fst_tbl <- function(format) {
 }
