@@ -63,7 +63,9 @@ tar_make_future <- function(
     callr_function = callr_function,
     callr_arguments = callr_arguments,
     envir = envir,
-    script = script
+    script = script,
+    store = store,
+    fun = "tar_make_future"
   )
   invisible(out)
 }
