@@ -17,6 +17,8 @@
 #' @param path Character, file path.
 #' @param pattern Character of length 1, a `grep` pattern for certain
 #'   assertions.
+#' @param args Character vector of expected function argument names.
+#'   Order matters.
 #' @examples
 #' tar_assert_chr("123")
 #' try(tar_assert_chr(123))
@@ -138,7 +140,8 @@ tar_assert_flag <- function(x, choices, msg = NULL) {
 tar_assert_format <- function(format) {
   tar_assert_scalar(format)
   tar_assert_chr(format)
-  store_assert_format_setting(as_class(format))
+  tar_assert_nzchar(format)
+  store_assert_format_setting(store_format_dispatch(format))
 }
 
 #' @export
@@ -158,6 +161,22 @@ tar_assert_function <- function(x, msg = NULL) {
   }
 }
 
+#' @export
+#' @rdname tar_assert
+tar_assert_function_arguments <- function(x, args, msg = NULL) {
+  exp <- as.character(names(formals(x)))
+  equal <- identical(exp, as.character(args))
+  msg <- paste(
+    "function",
+    deparse(substitute(x)),
+    "must have these exact arguments in this exact order:",
+    paste(exp, collapse = ", ")
+  )
+  if (!equal) {
+    tar_throw_validate(msg %|||% "input must be a function.")
+  }
+}
+
 #' @export
 #' @rdname tar_assert
 tar_assert_ge <- function(x, threshold, msg = NULL) {
@@ -462,7 +481,8 @@ tar_assert_store <- function(store) {
 #' @rdname tar_assert
 tar_assert_target <- function(x, msg = NULL) {
   msg <- msg %|||% paste(
-    "Found a non-target object. The target script file (default: _targets.R)",
+    "Found a non-target object in the target list.",
+    "The target script file (default: _targets.R)",
     "must end with a list of tar_target() objects (recommended)",
     "or a tar_pipeline() object (deprecated)."
   )
@@ -473,15 +493,13 @@ tar_assert_target <- function(x, msg = NULL) {
 #' @rdname tar_assert
 tar_assert_target_list <- function(x) {
   msg <- paste(
-    "Expected a list of target objects but did not find one.",
+    "Expected a list of target objects, but the object is not a list.",
     "Are you missing a target list at the end of your target script file?",
     "The target script file (e.g. _targets.R)",
-    "must end with a list of tar_target() objects.",
-    "Each element of the target list",
-    "must be a target object or nested list of target objects."
+    "must end with a list of tar_target() objects."
   )
   tar_assert_list(x, msg = msg)
-  map(x, tar_assert_target, msg = msg)
+  map(x, tar_assert_target)
 }
 
 tar_assert_script <- function(script) {
