@@ -1,4 +1,8 @@
 tar_test("packages are actually loaded", {
+  skip_on_cran()
+  skip_if_not_installed("clustermq")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   options(clustermq.scheduler = "multicore")
   tar_option_set(envir = environment())
   x <- tar_target_raw(
@@ -13,9 +17,12 @@ tar_test("packages are actually loaded", {
   expect_equal(tar_read(x), exp)
 })
 
-tar_test("clustermq iteration loop can wait and shut down workers", {
+tar_test("clustermq iteration loop can wait for and shut down workers", {
   skip_on_os("windows")
   skip_if_not_installed("clustermq")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
+  on.exit(options(clustermq.scheduler = old), add = TRUE)
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
   x <- tar_target_raw("x", quote(Sys.sleep(2)), garbage_collection = TRUE)
@@ -25,7 +32,6 @@ tar_test("clustermq iteration loop can wait and shut down workers", {
   out$run()
   target <- pipeline_get_target(pipeline, "y")
   expect_equal(target_read_value(target)$object$a, "x")
-  options(clustermq.scheduler = old)
 })
 
 tar_test("nontrivial common data with multicore", {
@@ -75,6 +81,10 @@ tar_test("nontrivial globals with global environment", {
 tar_test("prevent high-memory data via target objects", {
   # Run this test once inside tar_test() (test environment)
   # and once outside tar_test() global environment.
+  skip_on_cran()
+  skip_if_not_installed("clustermq")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   options(clustermq.scheduler = "multicore")
   t <- list(tar_target(x, runif(1e7), deployment = "main", format = "qs"))
   pipeline <- pipeline_init(list(t[[1]], tar_target(y, x)))
@@ -98,6 +108,8 @@ tar_test("prevent high-memory data via target objects", {
 })
 
 tar_test("heavily parallel workload should run fast", {
+  skip_on_cran()
+  skip_if_not_installed("clustermq")
   tar_script({
     library(targets)
     options(clustermq.scheduler = "multicore")
@@ -133,6 +145,8 @@ tar_test("heavily parallel workload should run fast", {
 })
 
 tar_test("profile heavily parallel workload", {
+  skip_on_cran()
+  skip_if_not_installed("clustermq")
   tar_script({
     library(targets)
     options(clustermq.scheduler = "multicore")
