@@ -7,6 +7,8 @@ tar_test("workerless deployment works", {
   skip_on_os("windows")
   skip_on_os("solaris")
   skip_if_not_installed("clustermq")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   x <- tar_target_raw("x", quote(1L), deployment = "main")
   y <- tar_target_raw("y", quote(x), deployment = "main")
   z <- tar_target_raw("z", quote(x + 1L), deployment = "main")
@@ -29,6 +31,8 @@ tar_test("semi-workerless deployment works", {
   skip_on_os("windows")
   skip_on_os("solaris")
   skip_if_not_installed("clustermq")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
   on.exit(options(clustermq.scheduler = old))
@@ -56,6 +60,8 @@ tar_test("some targets up to date, some not", {
   skip_if_not_installed("clustermq")
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   on.exit(options(clustermq.scheduler = old))
   x <- tar_target_raw("x", quote(1L))
   y <- tar_target_raw("y", quote(x))
@@ -80,6 +86,8 @@ tar_test("clustermq algo can skip targets", {
   skip_if_not_installed("clustermq")
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   on.exit(options(clustermq.scheduler = old))
   x <- tar_target_raw("x", quote(1L))
   y <- tar_target_raw("y", quote(x))
@@ -104,6 +112,8 @@ tar_test("nontrivial common data", {
   skip_if_not_installed("clustermq")
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   old_envir <- tar_option_get("envir")
   envir <- new.env(parent = globalenv())
   tar_option_set(envir = envir)
@@ -134,6 +144,8 @@ tar_test("clustermq with a dynamic file", {
   skip_if_not_installed("clustermq")
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   old_envir <- tar_option_get("envir")
   envir <- new.env(parent = globalenv())
   on.exit({
@@ -170,6 +182,8 @@ tar_test("branching plan", {
   skip_if_not_installed("clustermq")
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   on.exit(options(clustermq.scheduler = old))
   pipeline <- pipeline_map()
   out <- clustermq_init(pipeline, workers = 2L)
@@ -219,6 +233,8 @@ tar_test("cover the worker shutdown step in clustermq$iterate() event loop", {
   skip_if_not_installed("clustermq")
   old <- getOption("clustermq.scheduler")
   options(clustermq.scheduler = "multicore")
+  tar_runtime$set_fun("tar_make_clustermq")
+  on.exit(tar_runtime$unset_fun())
   on.exit(options(clustermq.scheduler = old))
   targets <- list(
     target_init("x1", quote(1)),
