@@ -14,8 +14,8 @@ tar_test("store_wait_correct_hash()", {
 
 tar_test("default serialization/unserialization methods", {
   store <- store_init()
-  expect_equal(store_serialize_object(store, "x"), "x")
-  expect_equal(store_unserialize_object(store, "x"), "x")
+  expect_equal(store_marshal_object(store, "x"), "x")
+  expect_equal(store_unmarshal_object(store, "x"), "x")
 })
 
 tar_test("store_validate()", {
